Compute the lower winsorization threshold for a given range specification
Source:R/normalize-x.R
get_bottom_n.RdCompute the lower winsorization threshold for a given range specification
R/normalize-x.R
get_bottom_n.RdCompute the lower winsorization threshold for a given range specification