Compute the upper winsorization threshold for a given range specification
Source:R/normalize-x.R
get_top_n.RdCompute the upper winsorization threshold for a given range specification
R/normalize-x.R
get_top_n.RdCompute the upper winsorization threshold for a given range specification