Resolve one or two candidate column names to a single numeric vector
Source:R/utils.R
resolve_col.RdGiven one or two candidate column names and a data frame, returns a single
numeric vector. If both columns are present, they are coalesced with the
first (990 PC) taking priority and the second (990-EZ) filling in where
the first is NA.